@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '1.08';
+  $CPAN::Perl::Releases::VERSION = '1.10';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -371,6 +371,10 @@ our $data =
     "tar.bz2" => "C/CO/CORION/perl-5.17.10.tar.bz2",
     "tar.gz" => "C/CO/CORION/perl-5.17.10.tar.gz",
   },
+  "5.17.11" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.17.11.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.17.11.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -479,7 +483,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 1.08
+version 1.10
 
 =head1 SYNOPSIS
 
